@@ -24,6 +24,10 @@ head(positives)
 controls <- southworthReplication[!is.na(southworthReplication$trueLogRr), ]
 plotTrueAndObserved(controls$logRr, controls$seLogRr, controls$trueLogRr)
 
+## ------------------------------------------------------------------------
+null <- fitNull(negatives$logRr, negatives$seLogRr)
+model <- convertNullToErrorModel(null)
+
 ## ------------------------------------------------------------------------
 model <- fitSystematicErrorModel(controls$logRr, controls$seLogRr, controls$trueLogRr)
 model
